@@ -24,8 +24,9 @@
 */
 
 /*
-** Bug reports and questions can be sent to kde-devel@kde.org
+** Bug reports and questions can be sent to <kde-devel@kde.org>
 */
+
 #define _GNU_SOURCE 1
 #include <features.h>
 #include <string.h>
@@ -399,8 +400,8 @@ StringList::operator String() const
 	String s="";
 	for(const_iterator it=begin(); it!=end(); it++) {
 		s+=(*it);
-		if(s.right()!=String("\n") && s.right()!=String("\r"))
-			s+="\n";
+		if(s.right()!=String("\n") && s.right()!=String("\r"))	//krazy:exclude=duoblequote_chars
+			s+="\n";	//krazy:exclude=duoblequote_chars
 	}
 	return s;
 }
